
## CATO-CLI - mutation.container.fqdn:
[Click here](https://api.catonetworks.com/documentation/#mutation-fqdn) for documentation on this operation.

### Usage for mutation.container.fqdn:

`catocli mutation container fqdn -h`
